@@ -18,11 +18,14 @@ from libtmux.common import tmux_cmd
 from libtmux.constants import (
     PANE_DIRECTION_FLAG_MAP,
     RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    OptionScope,
     PaneDirection,
     ResizeAdjustmentDirection,
 )
 from libtmux.formats import FORMAT_SEPARATOR
+from libtmux.hooks import HooksMixin
 from libtmux.neo import Obj, fetch_obj
+from libtmux.options import OptionsMixin
 
 if t.TYPE_CHECKING:
     import sys
@@ -43,7 +46,11 @@ logger = logging.getLogger(__name__)
 
 
 @dataclasses.dataclass()
-class Pane(Obj):
+class Pane(
+    Obj,
+    OptionsMixin,
+    HooksMixin,
+):
     """:term:`tmux(1)` :term:`Pane` [pane_manual]_.
 
     ``Pane`` instances can send commands directly to a pane, or traverse
@@ -90,6 +97,8 @@ class Pane(Obj):
        Accessed April 1st, 2018.
     """
 
+    default_option_scope: OptionScope | None = OptionScope.Pane
+    default_hook_scope: OptionScope | None = OptionScope.Pane
     server: Server
 
     def __enter__(self) -> Self:
@@ -312,30 +321,35 @@ class Pane(Obj):
         self,
         start: t.Literal["-"] | int | None = None,
         end: t.Literal["-"] | int | None = None,
-    ) -> str | list[str]:
+    ) -> list[str]:
         """Capture text from pane.
 
         ``$ tmux capture-pane`` to pane.
         ``$ tmux capture-pane -S -10`` to pane.
-        ``$ tmux capture-pane`-E 3` to pane.
-        ``$ tmux capture-pane`-S - -E -` to pane.
+        ``$ tmux capture-pane -E 3`` to pane.
+        ``$ tmux capture-pane -S - -E -`` to pane.
 
         Parameters
         ----------
-        start: [str,int]
+        start : str | int, optional
             Specify the starting line number.
             Zero is the first line of the visible pane.
             Positive numbers are lines in the visible pane.
             Negative numbers are lines in the history.
-            `-` is the start of the history.
+            ``-`` is the start of the history.
             Default: None
-        end: [str,int]
+        end : str | int, optional
             Specify the ending line number.
             Zero is the first line of the visible pane.
             Positive numbers are lines in the visible pane.
             Negative numbers are lines in the history.
-            `-` is the end of the visible pane
+            ``-`` is the end of the visible pane.
             Default: None
+
+        Returns
+        -------
+        list[str]
+            Captured pane content.
         """
         cmd = ["capture-pane", "-p"]
         if start is not None:
@@ -402,7 +416,7 @@ class Pane(Obj):
         self,
         cmd: str,
         get_text: t.Literal[True],
-    ) -> str | list[str]: ...
+    ) -> list[str]: ...
 
     @t.overload
     def display_message(self, cmd: str, get_text: t.Literal[False]) -> None: ...
@@ -411,7 +425,7 @@ class Pane(Obj):
         self,
         cmd: str,
         get_text: bool = False,
-    ) -> str | list[str] | None:
+    ) -> list[str] | None:
         """Display message to pane.
 
         Displays a message in target-client status line.
@@ -423,6 +437,11 @@ class Pane(Obj):
         get_text : bool, optional
             Returns only text without displaying a message in
             target-client status line.
+
+        Returns
+        -------
+        list[str] | None
+            Message output if get_text is True, otherwise None.
         """
         if get_text:
             return self.cmd("display-message", "-p", cmd).stdout
@@ -705,7 +724,12 @@ class Pane(Obj):
         Parameters
         ----------
         width : int
-            pane width, in cells
+            Pane width, in cells.
+
+        Returns
+        -------
+        :class:`Pane`
+            Self, for method chaining.
         """
         self.resize_pane(width=width)
         return self
@@ -716,7 +740,12 @@ class Pane(Obj):
         Parameters
         ----------
         height : int
-            height of pain, in cells
+            Pane height, in cells.
+
+        Returns
+        -------
+        :class:`Pane`
+            Self, for method chaining.
         """
         self.resize_pane(height=height)
         return self
