@@ -18,6 +18,8 @@ import warnings
 from libtmux import exc, formats
 from libtmux._internal.query_list import QueryList
 from libtmux.common import tmux_cmd
+from libtmux.constants import OptionScope
+from libtmux.hooks import HooksMixin
 from libtmux.neo import fetch_objs
 from libtmux.pane import Pane
 from libtmux.session import Session
@@ -30,6 +32,7 @@ from .common import (
     WindowDict,
     session_check_name,
 )
+from .options import OptionsMixin
 
 if t.TYPE_CHECKING:
     import types
@@ -44,7 +47,11 @@ if t.TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 
 
-class Server(EnvironmentMixin):
+class Server(
+    EnvironmentMixin,
+    OptionsMixin,
+    HooksMixin,
+):
     """:term:`tmux(1)` :term:`Server` [server_manual]_.
 
     - :attr:`Server.sessions` [:class:`Session`, ...]
@@ -117,6 +124,11 @@ class Server(EnvironmentMixin):
     formatter_prefix = "server_"
     """Namespace used for :class:`~libtmux.common.TmuxMappingObject`"""
 
+    default_option_scope: OptionScope | None = OptionScope.Server
+    """For option management."""
+    default_hook_scope: OptionScope | None = OptionScope.Server
+    """For hook management."""
+
     def __init__(
         self,
         socket_name: str | None = None,
@@ -301,7 +313,7 @@ class Server(EnvironmentMixin):
 
     @property
     def attached_sessions(self) -> list[Session]:
-        """Return active :class:`Session`s.
+        """Return active :class:`Session` instances.
 
         Examples
         --------
@@ -310,7 +322,8 @@ class Server(EnvironmentMixin):
 
         Returns
         -------
-        list of :class:`Session`
+        list[:class:`Session`]
+            Sessions that are attached.
         """
         return self.sessions.filter(session_attached__noeq="1")
 
@@ -475,10 +488,10 @@ class Server(EnvironmentMixin):
             when the command exits. NOTE: When this command exits the window
             will close.  This feature is useful for long-running processes
             where the closing of the window upon completion is desired.
-        x : [int, str], optional
+        x : int | str, optional
             Force the specified width instead of the tmux default for a
             detached session
-        y : [int, str], optional
+        y : int | str, optional
             Force the specified height instead of the tmux default for a
             detached session
 
