@@ -14,18 +14,21 @@ import typing as t
 import warnings
 
 from libtmux._internal.query_list import QueryList
-from libtmux.common import has_gte_version, tmux_cmd
+from libtmux.common import tmux_cmd
 from libtmux.constants import (
     RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    OptionScope,
     PaneDirection,
     ResizeAdjustmentDirection,
     WindowDirection,
 )
+from libtmux.hooks import HooksMixin
 from libtmux.neo import Obj, fetch_obj, fetch_objs
 from libtmux.pane import Pane
 
 from . import exc
-from .common import PaneDict, WindowOptionDict, handle_option_error
+from .common import PaneDict, WindowOptionDict
+from .options import OptionsMixin
 
 if t.TYPE_CHECKING:
     import sys
@@ -33,6 +36,7 @@ if t.TYPE_CHECKING:
 
     from libtmux._internal.types import StrPath
 
+    from .common import PaneDict, WindowOptionDict
     from .server import Server
     from .session import Session
 
@@ -46,7 +50,11 @@ logger = logging.getLogger(__name__)
 
 
 @dataclasses.dataclass()
-class Window(Obj):
+class Window(
+    Obj,
+    OptionsMixin,
+    HooksMixin,
+):
     """:term:`tmux(1)` :term:`Window` [window_manual]_.
 
     Holds :class:`Pane` objects.
@@ -101,6 +109,8 @@ class Window(Obj):
        https://man.openbsd.org/tmux.1#DESCRIPTION. Accessed April 1st, 2018.
     """
 
+    default_option_scope: OptionScope | None = OptionScope.Window
+    default_hook_scope: OptionScope | None = OptionScope.Window
     server: Server
 
     def __enter__(self) -> Self:
@@ -274,27 +284,32 @@ class Window(Obj):
         Parameters
         ----------
         attach : bool, optional
-            make new window the current window after creating it, default
+            Make new window the current window after creating it, default
             True.
         start_directory : str or PathLike, optional
-            specifies the working directory in which the new window is created.
+            Specifies the working directory in which the new window is created.
         direction : PaneDirection, optional
-            split in direction. If none is specified, assume down.
-        full_window_split: bool, optional
-            split across full window width or height, rather than active pane.
-        zoom: bool, optional
-            expand pane
+            Split in direction. If none is specified, assume down.
+        full_window_split : bool, optional
+            Split across full window width or height, rather than active pane.
+        zoom : bool, optional
+            Expand pane.
         shell : str, optional
-            execute a command on splitting the window.  The pane will close
+            Execute a command on splitting the window. The pane will close
             when the command exits.
 
-            NOTE: When this command exits the pane will close.  This feature
+            NOTE: When this command exits the pane will close. This feature
             is useful for long-running processes where the closing of the
             window upon completion is desired.
-        size: int, optional
+        size : int, optional
             Cell/row or percentage to occupy with respect to current window.
-        environment: dict, optional
-            Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
+        environment : dict, optional
+            Environmental variables for new pane. Passthrough to ``-e``.
+
+        Returns
+        -------
+        :class:`Pane`
+            The newly created pane.
         """
         active_pane = self.active_pane or self.panes[0]
         return active_pane.split(
@@ -357,10 +372,6 @@ class Window(Obj):
         2. Manual resizing: ``height`` and / or ``width``.
         3. Expand or shrink: ``expand`` or ``shrink``.
         """
-        if not has_gte_version("2.9"):
-            warnings.warn("resize() requires tmux 2.9 or newer", stacklevel=2)
-            return self
-
         tmux_args: tuple[str, ...] = ()
 
         # Adjustments
@@ -403,7 +414,7 @@ class Window(Obj):
         Parameters
         ----------
         layout : str, optional
-            string of the layout, 'even-horizontal', 'tiled', etc. Entering
+            String of the layout, 'even-horizontal', 'tiled', etc. Entering
             None (leaving this blank) is same as ``select-layout`` with no
             layout. In recent tmux versions, it picks the most recently
             set layout.
@@ -424,7 +435,17 @@ class Window(Obj):
                 Panes are spread out as evenly as possible over the window in
                 both rows and columns.
             'custom'
-                custom dimensions (see :term:`tmux(1)` manpages).
+                Custom dimensions (see :term:`tmux(1)` manpages).
+
+        Returns
+        -------
+        :class:`Window`
+            Self, for method chaining.
+
+        Raises
+        ------
+        :exc:`libtmux.exc.LibTmuxException`
+            If tmux returns an error.
         """
         cmd = ["select-layout"]
 
@@ -438,123 +459,6 @@ class Window(Obj):
 
         return self
 
-    def set_window_option(self, option: str, value: int | str) -> Window:
-        """Set option for tmux window.
-
-        Wraps ``$ tmux set-window-option <option> <value>``.
-
-        Parameters
-        ----------
-        option : str
-            option to set, e.g. 'aggressive-resize'
-        value : str
-            window option value. True/False will turn in 'on' and 'off',
-            also accepts string of 'on' or 'off' directly.
-
-        Raises
-        ------
-        :exc:`exc.OptionError`, :exc:`exc.UnknownOption`,
-        :exc:`exc.InvalidOption`, :exc:`exc.AmbiguousOption`
-        """
-        if isinstance(value, bool) and value:
-            value = "on"
-        elif isinstance(value, bool) and not value:
-            value = "off"
-
-        cmd = self.cmd(
-            "set-window-option",
-            option,
-            value,
-        )
-
-        if isinstance(cmd.stderr, list) and len(cmd.stderr):
-            handle_option_error(cmd.stderr[0])
-
-        return self
-
-    def show_window_options(self, g: bool | None = False) -> WindowOptionDict:
-        """Return dict of options for window.
-
-        .. versionchanged:: 0.13.0
-
-           ``option`` removed, use show_window_option to return an individual option.
-
-        Parameters
-        ----------
-        g : str, optional
-            Pass ``-g`` flag for global variable, default False.
-        """
-        tmux_args: tuple[str, ...] = ()
-
-        if g:
-            tmux_args += ("-g",)
-
-        tmux_args += ("show-window-options",)
-        cmd = self.cmd(*tmux_args)
-
-        output = cmd.stdout
-
-        # The shlex.split function splits the args at spaces, while also
-        # retaining quoted sub-strings.
-        #   shlex.split('this is "a test"') => ['this', 'is', 'a test']
-
-        window_options: WindowOptionDict = {}
-        for item in output:
-            try:
-                key, val = shlex.split(item)
-            except ValueError:
-                logger.exception("Error extracting option: %s", item)
-            assert isinstance(key, str)
-            assert isinstance(val, str)
-
-            if isinstance(val, str) and val.isdigit():
-                window_options[key] = int(val)
-
-        return window_options
-
-    def show_window_option(
-        self,
-        option: str,
-        g: bool = False,
-    ) -> str | int | None:
-        """Return option value for the target window.
-
-        todo: test and return True/False for on/off string
-
-        Parameters
-        ----------
-        option : str
-        g : bool, optional
-            Pass ``-g`` flag, global. Default False.
-
-        Raises
-        ------
-        :exc:`exc.OptionError`, :exc:`exc.UnknownOption`,
-        :exc:`exc.InvalidOption`, :exc:`exc.AmbiguousOption`
-        """
-        tmux_args: tuple[str | int, ...] = ()
-
-        if g:
-            tmux_args += ("-g",)
-
-        tmux_args += (option,)
-
-        cmd = self.cmd("show-window-options", *tmux_args)
-
-        if len(cmd.stderr):
-            handle_option_error(cmd.stderr[0])
-
-        window_options_output = cmd.stdout
-
-        if not len(window_options_output):
-            return None
-
-        value_raw = next(shlex.split(item) for item in window_options_output)
-
-        value: str | int = int(value_raw[1]) if value_raw[1].isdigit() else value_raw[1]
-
-        return value
-
     def rename_window(self, new_name: str) -> Window:
         """Rename window.
 
@@ -573,8 +477,6 @@ class Window(Obj):
         >>> window.rename_window('New name')
         Window(@1 1:New name, Session($1 ...))
         """
-        import shlex
-
         lex = shlex.shlex(new_name)
         lex.escape = " "
         lex.whitespace_split = False
@@ -652,11 +554,21 @@ class Window(Obj):
         Parameters
         ----------
         destination : str, optional
-            the ``target window`` or index to move the window to, default:
-            empty string
+            The ``target window`` or index to move the window to, default:
+            empty string.
         session : str, optional
-            the ``target session`` or index to move the window to, default:
+            The ``target session`` or index to move the window to, default:
             current session.
+
+        Returns
+        -------
+        :class:`Window`
+            Self, for method chaining.
+
+        Raises
+        ------
+        :exc:`libtmux.exc.LibTmuxException`
+            If tmux returns an error.
         """
         session = session or self.session_id
         proc = self.cmd(
@@ -694,11 +606,6 @@ class Window(Obj):
 
         Examples
         --------
-        .. ::
-            >>> import pytest
-            >>> from libtmux.common import has_lt_version
-            >>> if has_lt_version('3.2'):
-            ...     pytest.skip('This doctest requires tmux 3.2 or newer')
         >>> window_initial = session.new_window(window_name='Example')
         >>> window_initial
         Window(@... 2:Example, Session($1 libtmux_...))
@@ -900,7 +807,7 @@ class Window(Obj):
             # Deprecated in 3.1 in favor of -l
             warnings.warn(
                 f'Deprecated in favor of size="{str(percent).rstrip("%")}%" '
-                ' ("-l" flag) in tmux 3.1+.',
+                '(using the "-l" flag).',
                 category=DeprecationWarning,
                 stacklevel=2,
             )
@@ -973,6 +880,66 @@ class Window(Obj):
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
+    def set_window_option(
+        self,
+        option: str,
+        value: int | str,
+    ) -> Window:
+        """Set option for tmux window. Deprecated by :meth:`Window.set_option()`.
+
+        .. deprecated:: 0.26
+
+           Deprecated by :meth:`Window.set_option()`.
+
+        """
+        warnings.warn(
+            "Window.set_window_option() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.set_option(option=option, value=value)
+
+    def show_window_options(self, g: bool | None = False) -> WindowOptionDict:
+        """Show options for tmux window. Deprecated by :meth:`Window.show_options()`.
+
+        .. deprecated:: 0.26
+
+           Deprecated by :meth:`Window.show_options()`.
+
+        """
+        warnings.warn(
+            "Window.show_window_options() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.show_options(
+            global_=g or False,
+            scope=OptionScope.Window,
+        )
+
+    def show_window_option(
+        self,
+        option: str,
+        g: bool = False,
+    ) -> str | int | None:
+        """Return option for target window. Deprecated by :meth:`Window.show_option()`.
+
+        .. deprecated:: 0.26
+
+           Deprecated by :meth:`Window.show_option()`.
+
+        """
+        warnings.warn(
+            "Window.show_window_option() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.show_option(
+            option=option,
+            g=g,
+            scope=OptionScope.Window,
+        )
+
     def get(self, key: str, default: t.Any | None = None) -> t.Any:
         """Return key-based lookup. Deprecated by attributes.
 
